//
//  ENFileUtils.h
//  CoreNote
//
//  Created by Mustafa Furniturewala on 8/17/13.
//  Copyright (c) 2013 Evernote Corporation. All rights reserved.
//

#import <Foundation/Foundation.h>

@interface ENFileUtils : NSObject

+ (BOOL) createDirectoryIfNecessary:(NSString*)directory;
+ (BOOL) clearDirectory:(NSString*)directory;


/**
 * Grab the size of a file
 */
+ (unsigned long long) sizeOfFile: (NSString *) file;


/**
 * Make sure the specified filename is unique by appending numbers to it.
 * @return The new filename (or the original, if unchanged)
 */
+ (NSString *) ensureUniqueFilenameAndPreserveExtension: (NSString *) filename;


#if !TARGET_OS_IPHONE

/**
 * Returns the support folder for the application, used to store the
 * Core Data store file and other stuff.  This code uses a folder
 * named with the application's bundle identifier for the content, either in the
 * NSApplicationSupportDirectory location or (if the former cannot be
 * found), the system's temporary directory.
 *
 * If the directory does not already exist, it is created.
 *
 * This method is thread safe and should stay that way.
 */
+ (NSString *) applicationSupportFolder;


/**
 * Returns (and creates if it doesn't exist) the root directory where data for all
 * accounts is stored.
 */
+ (NSString *) rootAccountStorageDir;


/**
 * The directory where bootstrap/profile data is maintained.
 */
+ (NSString *)bootstrapDataDirectory;


/**
 * How many subdirectories in the specified dir
 */
+ (NSUInteger) directoryCountOfDirectoryAtPath: (NSString *) path;


#endif //!TARGET_OS_IPHONE

@end
