//
//  ENMLTransformer.h
//  CoreNote
//
//  Created by Steve White on 6/16/12.
//  Copyright (c) 2012 Evernote Corporation. All rights reserved.
//

#import <Foundation/Foundation.h>

@class ENCoreDataLocalStore;
@class ENNoteMOID;

@protocol ENMLIncrementalTransformDelegate;

@protocol ENMLTransformer <NSObject>

@required

+ (NSString *) transformedMimeType;
+ (NSString *) transformedFileExtension;
+ (BOOL) allowsIncrementalTransform;

- (void) setLocalStore:(ENCoreDataLocalStore *)localStore;
- (void) setNoteID:(ENNoteMOID *)noteID;

- (id) transformENMLContent:(NSString *)enmlContents;
- (id) transformContentOfENMLFile:(NSString *)enmlFile;

- (id) enmlFromTransformedContent:(NSString *)transformedContent;
- (id) enmlFromTransformedContentFile:(NSString *)transformedContentFile;

@optional

// These are used when allowsIncrementalTransform is YES

- (void) setTransformDelegate:(id<ENMLIncrementalTransformDelegate>)transformDelegate;

- (void) beginIncrementalTransformation;
- (void) appendIncrementalTransformData:(NSData *)data;
- (void) completeIncrementalTransformation;
- (void) cancelIncrementalTransformation;

- (void) beginReverseIncrementalTransformation;
- (void) appendReverseIncrementalTransformData:(NSData *)data;
- (void) completeReverseIncrementalTransformation;
- (void) cancelReverseIncrementalTransformation;

@end

@protocol ENMLIncrementalTransformDelegate <NSObject>

- (void) transformerDidStart:(id<ENMLTransformer>)transformer;
- (void) transformerDidStop:(id<ENMLTransformer>)transformer;
- (void) transformer:(id<ENMLTransformer>)transformer didGenerateString:(NSString *)string;
- (void) transformer:(id<ENMLTransformer>)transformer didFailWithError:(NSError *)error;

@end
