//
//  ENSegmentedDataCache.h
//  Evernote
//
//  Created by Steve White on 9/23/10.
//  Copyright 2010 Evernote Corporation. All rights reserved.
//

#import <Foundation/Foundation.h>

typedef struct {
  uint32_t length;
  uint32_t offset;
  uint16_t segment;
  BOOL dirty;
} ENSegmentedDataCacheRecord;

@interface ENSegmentedDataCache : NSObject

- (id) initWithCacheDirectory:(NSString *)directory
                  segmentSize:(size_t)segmentSize
      maximumNumberOfSegments:(uint8_t)maxSegmentCount
            overwriteExisting:(BOOL)overwriteExisting;

- (void) close;

- (BOOL) setDataRef:(CFDataRef)dataRef forKey:(uint32_t)key;
- (BOOL) setDataRef:(CFDataRef)dataRef 
         withHeader:(void *)header 
             length:(size_t)headerLength 
             forKey:(uint32_t)key;

- (CFDataRef) newDataRefForKey:(uint32_t)key 
                       isDirty:(BOOL *)dirty
                    withHeader:(void *)header;
- (CFDataRef) newDataRefForKey:(uint32_t)key;
- (NSDictionary *) dataRefsForKeys:(NSArray *)keys;

- (void) removeRecordForKey:(uint32_t)key;
- (NSArray *) allKeys;
- (NSUInteger) numberOfKeys;
- (BOOL) keyExists:(uint32_t)key;
- (BOOL) keyExists:(uint32_t)key isDirty:(BOOL *)isDirty;
- (void) changeKeyFrom:(uint32_t)oldKey to:(uint32_t)newKey;
- (void) setDirty:(BOOL)dirty forKey:(uint32_t)key;
- (BOOL) isKeyDirty:(uint32_t)key;

- (void) mapAllSegments;
- (void) clearCache;

@end
