//
//  ENXMLUtils.h
//  CoreNote
//
//  Created by Steve White on 10/24/11.
//  Copyright (c) 2011 Evernote Corporation. All rights reserved.
//

#import <Foundation/Foundation.h>

#include <libxml/tree.h>
#include <libxml/xmlstring.h>

static inline NSString * NSStringFromXmlCharWithLength( const xmlChar * ch, size_t length) {
  if (ch == NULL) {
    return (nil);
  }
  
  return ([[NSString allocWithZone: nil] initWithBytes: ch
                                                length: length
                                              encoding: NSUTF8StringEncoding]);
}

static inline NSString * NSStringFromXmlChar( const xmlChar * ch ) {
  if (ch == NULL) {
    return (nil);
  }
  
  return NSStringFromXmlCharWithLength(ch, strlen((const char *)ch));
}


static inline const xmlChar * xmlCharFromNSString( NSString *input ) {
  return (const xmlChar *)[input cStringUsingEncoding:NSUTF8StringEncoding];
}

static inline NSString * NSStringFromXmlNodeType(int nodeType) {
  switch (nodeType) {
    case XML_ELEMENT_NODE:
      return @"XML_ELEMENT_NODE";
    case XML_ATTRIBUTE_NODE:
      return @"XML_ATTRIBUTE_NODE";
    case XML_TEXT_NODE:
      return @"XML_TEXT_NODE";
    case XML_CDATA_SECTION_NODE:
      return @"XML_CDATA_SECTION_NODE";
    case XML_ENTITY_REF_NODE:
      return @"XML_ENTITY_REF_NODE";
    case XML_ENTITY_NODE:
      return @"XML_ENTITY_NODE";
    case XML_PI_NODE:
      return @"XML_PI_NODE";
    case XML_COMMENT_NODE:
      return @"XML_COMMENT_NODE";
    case XML_DOCUMENT_NODE:
      return @"XML_DOCUMENT_NODE";
    case XML_DOCUMENT_TYPE_NODE:
      return @"XML_DOCUMENT_TYPE_NODE";
    case XML_DOCUMENT_FRAG_NODE:
      return @"XML_DOCUMENT_FRAG_NODE";
    case XML_NOTATION_NODE:
      return @"XML_NOTATION_NODE";
    case XML_HTML_DOCUMENT_NODE:
      return @"XML_HTML_DOCUMENT_NODE";
    case XML_DTD_NODE:
      return @"XML_DTD_NODE";
    case XML_ELEMENT_DECL:
      return @"XML_ELEMENT_DECL";
    case XML_ATTRIBUTE_DECL:
      return @"XML_ATTRIBUTE_DECL";
    case XML_ENTITY_DECL:
      return @"XML_ENTITY_DECL";
    case XML_NAMESPACE_DECL:
      return @"XML_NAMESPACE_DECL";
    case XML_XINCLUDE_START:
      return @"XML_XINCLUDE_START";
    case XML_XINCLUDE_END:
      return @"XML_XINCLUDE_END";
  }
  return @"<unknown>";
}