//
//  ENMIMEUtils+ENSharedUtilities.h
//  Evernote
//
//  Created by Andrew McGeachie on 11/8/07.
//  Copyright 2007 Evernote, Corp. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import <CoreNote/ENMIMEUtils.h>

extern NSString * const kENPDFMIMEType;

// word
extern NSString * const kENMSWordMIMEType;
extern NSString * const kENMSWordOpenXMLMIMEType;

// powerpoint
extern NSString * const kENMSPowerPointMIMEType;
extern NSString * const kENMSPowerPointSlideshowMIMEType;
extern NSString * const kENMSPowerPointOpenXMLMIMEType;

// excel
extern NSString * const kENMSExcelMIMEType;
extern NSString * const kENMSExcelOpenXMLMIMEType;

// iwork
extern NSString * const kENMSiWorkPagesMIMEType;
extern NSString * const kENMSiWorkNumbersMIMEType;
extern NSString * const kENMSiWorkKeynoteMIMEType;

extern NSString *const kENZipFileMIMEType;
extern NSString *const kENZipFile2MIMEType;

@interface ENMIMEUtils (ENSharedUtilities)


/**
 * Indicates if the specified mime type is one that will be displayed inline
 * in the note.  We need to make sure the inlined ones have the proper extension
 * or WebKit will get all snarly on us.
 */
+ (BOOL) mimeTypeIsInlined: (NSString *) mime;


/**
 * Indicates if the specified mime type is an image that will be displayed inline
 */
+ (BOOL) mimeTypeIsInlinedImage: (NSString *) mime;


/**
 * Determine the mime-type for the specified file.
 */
+ (NSString *) mimeTypeForFile: (NSString *) filename;


/**
 * Given a file extension, determine the MIME type.
 */
+ (NSString *) mimeTypeForFileExtension: (NSString *) extension;


/*
 * Legacy support for audio resources that used to be inlined.  See [ENResourceMO fileExtension]
 *
 * for inlined content, we need the file extension to be legit, or webkit won't inline stuff properly
 * for us.  Revisions including and prior to 49207 displayed audio inlined.  Now we display audio
 * as a file attachment.  However, we can't change the way the extension is determined or existing
 * user's audio-resource-data-file names could change, rendering them poopoo.  Hence, mimeTypeIsFormerlyInlinedAudio
 */
+ (BOOL) mimeTypeIsFormerlyInlinedAudio: (NSString *) mime;


/**
 * Get a generic filename (e.g. Audio.wav, Image.jpg) for a given MIME type.
 */
+ (NSString *) genericFilenameForMIMEType: (NSString *) mime;


@end
