//
//  ENScreenshotHelper.h
//  EverNote
//
//  Created by Brandon Volbright on 2/2/12.
//  Copyright (c) 2012 Evernote. All rights reserved.
//

#import <Foundation/Foundation.h>

#import <ENSharedUtilities/ENSelectorWindow.h>


typedef void (^ENScreenshotHelperImageCapturedBlock)(NSData *imageData);

@interface ENScreenshotHelper : NSObject {
  ENScreenshotHelperImageCapturedBlock mBlock;
  NSRect mGlobalRect;
  NSPoint mOriginPoint;
  NSMutableArray* mViewArray;
  NSMutableArray* mWindowArray;
}

@property (readonly) BOOL isBusy;
@property (retain) NSMutableArray* viewArray;
@property (retain) NSMutableArray* windowArray;

// callbacks from views
- (void)mouseMovedAtGlobalPoint:(NSPoint)globalPoint;
- (void)startDragAtGlobalPoint:(NSPoint)globalPoint;
- (void)continueDragAtGlobalPoint:(NSPoint)globalPoint;
- (void)stopDragAtGlobalPoint:(NSPoint)globalPoint;

/**
 * Capture an interactive screenshot (presenting crosshairs, letting user select either a rect
 * or a window). On success, call the given block with PNG image data.
 */
- (void)captureScreenshotAndCallBlock:(ENScreenshotHelperImageCapturedBlock)block;

/**
 * Capture non-interactive screenshot of the entire screen. On success, call the given block
 * with PNG image data.
 */
- (void)captureFullScreenshotAndCallBlock:(ENScreenshotHelperImageCapturedBlock)block;

/**
 * Cancel an interactive screenshot in progress.
 */
- (IBAction)cancelScreenshot:(id)sender;

/**
 * Helper method moved to here as a class method
 */
+ (NSRect) calcSelectedRectFromOrigin: (NSPoint) origin andMouseLocation: (NSPoint) mouseLocation;

/**
 * Helper method moved to here as a class method
 */
- (void)selectorWindowDidCancelScreenShot;

@end
