//
//  ENSocialProfile.h
//  EvernotePeople
//
//  Created by Alexey Shevchik on 10/5/12.
//  Copyright (c) 2012 Evernote Corporation. All rights reserved.
//

#import <Foundation/Foundation.h>

typedef enum ENSocialProfileType: NSUInteger{
  ENSocialProfileLinkedIn     = 1 << 0,
  ENSocialProfileFacebook     = 1 << 1,
  ENSocialProfileAddressBook  = 1 << 2
} ENSocialProfileType;

@interface ENSocialProfile : NSObject <NSCopying>

@property (nonatomic, copy) NSString *requestID;

@property (nonatomic, copy) NSString * firstName;
@property (nonatomic, copy) NSString * lastName;
@property (nonatomic, copy) NSString * formattedName;
@property (nonatomic, assign) ENSocialProfileType nameSource;

@property (nonatomic, copy) NSSet * emailAddresses;
@property (nonatomic, copy) NSSet * twitterAccounts;
@property (nonatomic, copy) NSSet * weiboAccounts;
// NSSet of ENPhoneNumber
@property (nonatomic, copy) NSSet * phoneNumbers;
// NSSet of ENIMAccount
@property (nonatomic, copy) NSSet * imAccounts;
// NSSet of ENWebsiteURL
@property (nonatomic, copy) NSSet * websiteURLs;

@property (nonatomic, copy) NSString * headline;
@property (nonatomic, assign) ENSocialProfileType headlineSource;
@property (nonatomic, copy) NSString * jobTitle;
@property (nonatomic, assign) ENSocialProfileType jobTitleSource;
@property (nonatomic, copy) NSString * company;
@property (nonatomic, assign) ENSocialProfileType companySource;
@property (nonatomic, copy) NSString * location;
@property (nonatomic, assign) ENSocialProfileType locationSource;
@property (nonatomic, copy) NSNumber * distance;
@property (nonatomic, copy) NSString * distanceString;

@property (nonatomic, copy) NSArray * affiliations;
@property (nonatomic, copy) NSArray * educations;
@property (nonatomic, copy) NSArray * employers;

@property (nonatomic, copy) NSString * uidFacebook;
@property (nonatomic, copy) NSString * uidLinkedIn;
@property (nonatomic, copy) NSString * personIDLinkedIn;
@property (nonatomic, copy) NSString * profileURLLinkedInPublic;
// the URL to the member's authenticated profile on LinkedIn (requires a login to be viewed, unlike public profiles)
// from http://developer.linkedin.com/documents/profile-api
@property (nonatomic, copy) NSString * profileURLLinkedInSiteStandardRequest;
@property (nonatomic, copy) NSString * profileURLFacebook;
@property (nonatomic, copy) NSString * avatarURLLinkedIn;
@property (nonatomic, copy) NSString * avatarURLFacebookSmall;
@property (nonatomic, copy) NSString * avatarURLFacebookBig;
@property (nonatomic, copy) NSString * avatarPathLocalFile;

@property (nonatomic, copy) NSString *uidAddressBook;
// NSArray of ENAddress
@property (nonatomic, copy) NSArray * addressList;
@property (nonatomic, copy) NSString * additionalNotes;
@property (nonatomic, strong) NSData * addressBookAvatarData;

@property (readwrite) ENSocialProfileType profileType;

+ (NSArray *) arrayOfPersonWithLinkedInPeopleSearch:(NSDictionary *)peopleSearchDictionary;
+ (id) personWithLinkedInDictionary:(id)linkedInDictionary;
+ (id) personWithFaceBookAffiliationsDictionary:(NSDictionary *)faceBookDictionary;
+ (id) personWithAddressBookProfile: (id)addressBookProfile;
+ (id) personWithParsedContactInfo:(id)contactInfoDictionary;

+(NSString *)compositeLinkedInIdFromPersonId:(NSString*)personId headerName:(NSString*)headerName headerValue:(NSString*)headerValue distance:(NSNumber*)distance;
+(NSString *)personIdFromLinkedInId:(NSString*)linkedInId;
+(NSString *)headerNameFromLinkedInId:(NSString*)linkedInId;
+(NSString *)headerValueFromLinkedInId:(NSString*)linkedInId;
+(NSNumber *)distanceValueFromLinkedInId:(NSString*)linkedInId;

- (NSString*)shortDescription;
- (NSString*)description;

- (void)mergeWithTwitterSet: (NSSet *)twitterSet;
- (void)mergeWithSinaWeiboSet: (NSSet *)weiboSet;
- (void)mergeWithEmailSet:(NSSet *)emailSet;
- (void)mergeWithPhoneNumberSet: (NSSet *)phoneSet;
- (void)mergeWithWebsiteSet: (NSSet *)websiteSet;
- (void)mergeWithAddress:(NSString *)address label:(NSString *)aLabel;

@end

@interface ENPhoneNumber : NSObject

@property (copy) NSString* number;
@property (copy) NSString* type;

+ (NSString *)plainPhoneNumberForPhoneNumberString:(NSString *)phoneNumberString;
+ (ENPhoneNumber *)phoneNumberWithNumber:(NSString *)aNumber type:(NSString *)phoneType;
- (NSString *)description;

@end

@interface ENAffiliation : NSObject

@property (copy) NSNumber * nid;
@property (copy) NSString * type;
@property (copy) NSString * name;

+ (NSArray *) affiliationsWithArray:(NSArray *)arrayOfAffiliations;
+ (id) affilationWithDictionary:(NSDictionary *)aDictionary;
- (NSString *)description;

@end

@interface ENEmployer : NSObject

@property (copy) NSNumber * nid;
@property (copy) NSString * name;

+ (NSArray *)employersWithArray:(NSArray *)arrayOfEmployers;
+ (ENEmployer *)employerWithDictionary:(NSDictionary *)aDictionary;
- (NSString *)description;

@end

@interface ENEducation : NSObject

@property (copy) NSNumber * nid;
// NSArray of NSString
@property (copy) NSArray * concentrations;
@property (copy) NSString * schoolName;
@property (copy) NSString * schoolType;

+ (NSArray *)educationsWithArray:(NSArray *)arrayOfEducations;
- (NSString *)concentrationsDescription;
- (NSString *)description;

@end

@interface ENIMAccount : NSObject

@property (copy) NSString * userName;
@property (copy) NSString * label;
@property (copy) NSString * type;

+ (ENIMAccount *)imAccountWithUserName:(NSString *)userName label:(NSString *)label type:(NSString *)type;
- (NSString *)description;

@end

// addressDictionary keys
extern NSString * const kENAddressStreetKey;
extern NSString * const kENAddressCityKey;
extern NSString * const kENAddressStateKey;
extern NSString * const kENAddressZIPKey;
extern NSString * const kENAddressCountryKey;
extern NSString * const kENAddressCountryCodeKey;
@interface ENAddress : NSObject

@property (copy) NSString *label;
@property (copy) NSDictionary *addressDictionary;
@property (copy) NSString *formattedAddress;

+ (ENAddress *)addressWithLabel:(NSString *)label detailsDictionary:(NSDictionary *)detailsDictionary;
+ (ENAddress *)addressWithLabel:(NSString *)label detailsString:(NSString *)addressString;
- (NSString *)description;

@end

@interface ENEmail : NSObject

@property (copy) NSString *label;
@property (copy) NSString *address;

+ (ENEmail *)emailWithLabel:(NSString *)label address:(NSString *)address;
- (NSString *)description;

@end

@interface ENWebsiteURL : NSObject

@property (copy) NSString *label;
@property (copy) NSString *address;

+ (ENWebsiteURL *)websiteURLWithLabel:(NSString *)label address:(NSString *)address;
- (NSString *)description;

@end