//
//  GAMTracker.h
//  GAMKit
//
//  Created by Isaac Wankerl on 11/12/13.
//  Copyright (c) 2013 Evernote Corp. All rights reserved.
//

#import <Foundation/Foundation.h>

@protocol GAMTracker<NSObject>

/*!
 Name of this tracker.
 */
@property(nonatomic, readonly) NSString *name;

/*!
 Set a tracking parameter.

 @param parameterName The parameter name.

 @param value The value to set for the parameter. If this is nil, the
 value for the parameter will be cleared.
 */
- (void)set:(NSString *)parameterName value:(NSString *)value;

/*!
 Get a tracking parameter.

 @param parameterName The parameter name.

 @returns The parameter value, or nil if no value for the given parameter is
 set.
 */
- (NSString *)get:(NSString *)parameterName;

/*!
 Queue tracking information with the given parameter values.

 @param parameters A map from parameter names to parameter values which will be
 set just for this piece of tracking information, or nil for none.
 */
- (void)send:(NSDictionary *)parameters;




/*!
 Queue an event hit

 @param category The category as an NSString. Passing nil is allowed by the API but may not produce the reporting results you want.
 @param action   The action as an NSString. Passing nil is allowed by the API but may not produce the reporting results you want.
 @param label    The label as an NSString or nil.
 @param value    The value as an NSNumber or nil.
 */
- (void)sendEventWithCategory:(NSString *)category action:(NSString *)action label:(NSString *)label value:(NSNumber *)value;

/*!
 Queue a pageview

 In addition to sending a kGAMHitType of kGAMAppView event with the pageName,
 this method will also set kGAMScreenName on the tracker to pageName so that future
 events will report which screen they occur on.  This is to be consistent with how
 the official Google iOS SDK works when using GAITrackedViewController for tracking
 page views. You can explicitly clear the kGAMScreenName on the tracker by setting
 it to nil.

 @param pageName The name of the page/screen
 */
- (void)sendPageViewWithPage:(NSString *)pageName;

/*!
 Queue a user timing event

 @param category             The user timing category as an NSString or nil.
 @param intervalMilliseconds The user timing length of time in milliseconds as an NSNumber. Passing nil is allowed by the API but may not produce the reporting results you want.
 @param name                 The user timing variable name as an NSString or nil.
 @param label                The user timing label as an NSString or nil.
 */
- (void)sendTimingWithCategory:(NSString *)category interval:(NSNumber *)intervalMilliseconds name:(NSString *)name label:(NSString *)label;

@end
